@@ -38,9 +38,9 @@ from .utils import (
 )
 
 # TODO: Do we want to do some arithmetic on types here?
-ArrayType = Union[List, "np.ndarray", "torch.tensor"]
-SeqLikeType = Union[str, Seq, SeqRecord, list, "SeqLike", "np.ndarray", "torch.tensor"]
+ArrayType = Union[list, np.ndarray,]
 StringLikeType = Union[str, Seq, SeqRecord]
+SeqLikeType = Union[ArrayType, StringLikeType, "SeqLike"]
 
 seqrecord_attrs = (
     "id",
@@ -72,16 +72,17 @@ class SeqLike:
     Here's a quick usage example:
 
     ```python
+    from seqlike import SeqLike
     example = 'ATCGATC'
 
-    seq_record = SeqLike(example).to_seqrecord()
-    seq = SeqLike(example).to_seq()
-    seq_str = SeqLike(example).to_str()
-    seq_index = SeqLike(example).to_index()
-    seq_onehot = SeqLike(example).to_onehot()
+    seq_record = SeqLike(example, seq_type="nt").to_seqrecord()
+    seq = SeqLike(example, seq_type="nt").to_seq()
+    seq_str = SeqLike(example, seq_type="nt").to_str()
+    seq_index = SeqLike(example, seq_type="nt").to_index()
+    seq_onehot = SeqLike(example, seq_type="nt").to_onehot()
     ```
 
-    Any of theose representations can be generated or passed in as an input.
+    Any of the aformentioned representations can be generated or passed in as an input.
     If using onehot or index encodings, they are of the shape:
     (N x NUM_BASES) and (N), respectively.
     We use symbols from our extended nucleotide and protein alphabets.
@@ -103,10 +104,6 @@ class SeqLike:
     The constructor also takes optional keyword arguments
     that are passed on to SeqRecord.
     For the id attribute, if unspecified we generate a random hexadecimal UUID.
-    The optional seq_type argument is one of 'DNA', 'RNA', 'NT', or 'AA'.
-    If seq_type is None, we try to infer this with the following simple rule:
-    if the sequence is entirely made of -ACGTUN, we assume it's an NT,
-    otherwise we use an AA.
 
     `codon_map` defines back-translation from an AA sequence to a NT sequence.
     This is formatted as a callable, see `codon_tables.py` for more info.
@@ -528,7 +525,7 @@ class SeqLike:
     def upper(self):
         """Return uppercase sequences and alphabet.
 
-        #noqa: DAR201
+        <!-- #noqa: DAR201 -->
         """
         seq_copy = deepcopy(self)
         seq_copy._seqrecord = seq_copy._seqrecord.upper()
@@ -576,7 +573,7 @@ class SeqLike:
     def __str__(self) -> str:
         """Cast to a string
 
-        #noqa: DAR201
+        <!-- #noqa: DAR201 -->
         """
         return self.to_str()
 
@@ -586,7 +583,7 @@ class SeqLike:
         If both nucleotide and an associated amino acid sequence are present,
         we show both.
 
-        #noqa: DAR201
+        <!-- #noqa: DAR201 -->
         """
         if self._type == "NT":
             return f"*** NT: {self._nt_record.__repr__()} \n\nAA: {self._aa_record.__repr__()}"
@@ -622,8 +619,8 @@ class SeqLike:
 
         We prioritize setting attribute in _seqrecord before the SeqLike object.
 
-        #noqa: DAR101
-        #noqa: DAR201
+        <!-- #noqa: DAR101 -->
+        <!-- #noqa: DAR201 -->
         """
 
         if name in seqrecord_attrs:
@@ -642,7 +639,7 @@ class SeqLike:
         :raises AttributeError: if the attribute is not a SeqLike
             or SeqRecord attribute.
 
-        #noqa: DAR201
+        <!-- #noqa: DAR201 -->
         """
         if name == "__setstate__":  # pertains to pickling
             raise AttributeError
@@ -795,8 +792,8 @@ class SeqLike:
     def __radd__(self, other: "SeqLike"):
         """Support for sum()
 
-        #noqa: DAR101
-        #noqa: DAR201
+        <!-- #noqa: DAR101 -->
+        <!-- #noqa: DAR201 -->
         """
         if other == 0:
             return self
@@ -806,8 +803,8 @@ class SeqLike:
     def __deepcopy__(self, memo):
         """Deepcopy implementation.
 
-        #noqa: DAR101
-        #noqa: DAR201
+        <!-- #noqa: DAR101 -->
+        <!-- #noqa: DAR201 -->
         """
         seq_copy = SeqLike(
             self.to_seqrecord(),
@@ -863,8 +860,8 @@ def _construct_seqlike(sequence, seq_type, alphabet, codon_map, **kwargs) -> tup
     When we pass in a SeqLike object,
     all relevant attributes are deep-copied over.
 
-    #noqa: DAR101
-    #noqa: DAR201
+    <!-- #noqa: DAR101 -->
+    <!-- #noqa: DAR201 -->
     """
     _type = deepcopy(sequence._type)
     _aa_record = record_from(deepcopy(sequence._aa_record), **kwargs)
@@ -892,7 +889,7 @@ def _construct_seqlike(sequence, seq_type, alphabet, codon_map, **kwargs) -> tup
 
 
 @dispatch(
-    (list, np.ndarray, str, Seq, SeqRecord),  # TODO: Figure out a way to include torch tensors w/o requiring torch
+    ArrayType.__args__ + StringLikeType.__args__, # TODO: Figure out a way to include torch tensors w/o requiring torch
     (str),
     (str, type(None)),
     (object, type(None)),
@@ -900,8 +897,8 @@ def _construct_seqlike(sequence, seq_type, alphabet, codon_map, **kwargs) -> tup
 def _construct_seqlike(sequence, seq_type, alphabet, codon_map, **kwargs) -> tuple:
     """Return attributes to set a SeqLike object from str, Seq, and SeqRecord objects.
 
-    #noqa: DAR101
-    #noqa: DAR201
+    <!-- #noqa: DAR101 -->
+    <!-- #noqa: DAR201 -->
     """
     validate_codon_map(codon_map)
 
@@ -955,13 +952,13 @@ def validate_codon_map(codon_map) -> None:
             raise TypeError(err_msg)
 
 
-@dispatch((str, Seq, SeqRecord), str)
+@dispatch(StringLikeType.__args__, str)
 def validate_sequence(sequence, _type) -> None:
     """Validate str, Seq, or SeqRecord sequence objects.
 
     :raises TypeError: when the sequence is an invalid for its sequence type.
 
-    #noqa: DAR101
+    <!-- #noqa: DAR101 -->
     """
     validation_func = {
         "NT": is_NT,
@@ -976,13 +973,13 @@ def validate_sequence(sequence, _type) -> None:
         raise TypeError(err_msg[_type])
 
 
-@dispatch((list, np.ndarray), str)
+@dispatch(ArrayType.__args__, str)
 def validate_sequence(sequence, _type) -> None:
     """Validate array-like sequence representations.
 
     :raises ValueError: when the shape of the sequence is not correct.
 
-    #noqa: DAR101
+    <!-- #noqa: DAR101 -->
     """
     sequence = np.asarray(sequence, dtype=float)
     if sequence.ndim not in (1, 2):
@@ -996,7 +993,7 @@ def validate_sequence(sequence, _type) -> None:
 def validate_sequence(sequence, _type):
     """We do not need to validate SeqLike sequences. (I think.)
 
-    #noqa: DAR101
+    <!-- #noqa: DAR101 -->
     """
     pass
 
@@ -1069,38 +1066,38 @@ def swap_representation(s: SeqLike) -> SeqLike:
     return sc
 
 
-@dispatch(str, type(None), (str, Seq, SeqRecord, SeqLike))
+@dispatch(str, type(None), StringLikeType.__args__+ArrayType.__args__)
 def determine__type_and_alphabet(seq_type, alphabet, sequence):
     """Determine _type and alphabet when _type is set and alphabet is None.
 
-    #noqa: DAR101
-    #noqa: DAR201
+    <!-- #noqa: DAR101 -->
+    <!-- #noqa: DAR201 -->
     """
     _type = SEQTYPE_TO_TYPE_MAPPING.get(seq_type)
     alphabet = determine_alphabet(_type, sequence)
     return _type, alphabet
 
 
-@dispatch(str, str, (list, np.ndarray, str, Seq, SeqRecord, SeqLike))
+@dispatch(str, str, StringLikeType.__args__+ArrayType.__args__)
 def determine__type_and_alphabet(seq_type, alphabet, sequence):
     """Determine _type and alphabet when _type is set and alphabet is set.
 
-    #noqa: DAR101
-    #noqa: DAR201
+    <!-- #noqa: DAR101 -->
+    <!-- #noqa: DAR201 -->
     """
     _type = SEQTYPE_TO_TYPE_MAPPING.get(seq_type)
     return _type, alphabet
 
 
-@dispatch(str, (str, Seq, SeqRecord, SeqLike))
+@dispatch(str, StringLikeType.__args__)
 def determine__type(alphabet, sequence) -> str:
     """Determine _type when alphabet is set.
 
     This function uses _only_ the sequence to determine the alphabet.
     We prioritize the amino acid representation where possible.
 
-    #noqa: DAR101
-    #noqa: DAR201
+    <!-- #noqa: DAR101 -->
+    <!-- #noqa: DAR201 -->
     """
     if alphabet == AA or alphabet == STANDARD_AA:
         return "AA"
@@ -1108,14 +1105,14 @@ def determine__type(alphabet, sequence) -> str:
         return "NT"
 
 
-@dispatch(str, (str, Seq, SeqRecord, SeqLike))
+@dispatch(str, StringLikeType.__args__+(SeqLike,))
 def determine_alphabet(_type, sequence) -> str:
     """Determine alphabet from _type and sequence.
 
     Enables us to use _type _and_ sequence to control the alphabet.
 
-    #noqa: DAR101
-    #noqa: DAR201
+    <!-- #noqa: DAR101 -->
+    <!-- #noqa: DAR201 -->
     """
     # _type = determine_seq_type(seq_type, sequence)
     alphabet = {"NT": NT, "AA": AA, "DNA": NT, "RNA": NT}.get(_type)
@@ -1134,8 +1131,8 @@ def array_to_string(sequence: Union[list, np.ndarray], _index_encoder, _onehot_e
     :raises IndexError: if the alphabet of the sequence is a superset
         of the index encoder and one-hot encoder object.
 
-    #noqa: DAR101
-    #noqa: DAR201
+    <!-- #noqa: DAR101 -->
+    <!-- #noqa: DAR201 -->
     """
     sequence = np.asarray(sequence, dtype=float)
     if sequence.ndim == 1:
@@ -1167,7 +1164,7 @@ def record_from(sequence, **kwargs) -> SeqRecord:
     return sequence
 
 
-@dispatch((list, np.ndarray))
+@dispatch(ArrayType.__args__)
 def record_from(sequence, **kwargs) -> SeqRecord:
     """Construct SeqRecord from array-like sequences.
 
